package com.actionsoft.apps.wechat.demo.event;

import com.actionsoft.bpms.commons.wechat.WechatProcessor;
import com.actionsoft.bpms.commons.wechat.bean.WechatConsts;
import com.actionsoft.bpms.commons.wechat.bean.WechatInMessage;
import com.actionsoft.bpms.commons.wechat.bean.WechatOutImageMessage;
import com.actionsoft.bpms.commons.wechat.bean.WechatOutMessage;
import com.actionsoft.bpms.commons.wechat.bean.WechatOutNewsMessage;
import com.actionsoft.bpms.commons.wechat.bean.WechatOutTextMessage;
import com.actionsoft.bpms.commons.wechat.bean.WechatOutVideoMessage;
import com.actionsoft.bpms.commons.wechat.bean.WechatOutVoiceMessage;

public class ProcessorNormalMssageDemo implements WechatProcessor {

	public WechatOutMessage handleMessage(WechatInMessage msg) {
		System.out.println("Event=" + msg.getEvent());
		System.out.println("Key=" + msg.getEventKey());
		// -------演示处理消息---------
		if (msg.getMsgType().equals(WechatConsts.MSG_TYPE_TEXT)) {
			System.out.println("这是文本消息");
			System.out.println("内容是：" + msg.getContent());
		} else if (msg.getMsgType().equals(WechatConsts.MSG_TYPE_IMAGE)) {
			System.out.println("这是图片消息");
			System.out.println("图片链接：" + msg.getPicUrl());
			System.out.println("图片媒体文件id：" + msg.getMediaId());
		} else if (msg.getMsgType().equals(WechatConsts.MSG_TYPE_VOICE)) {
			System.out.println("这是语音消息");
			System.out.println("语音格式：" + msg.getFormat());
			System.out.println("语音媒体文件id：" + msg.getMediaId());
		} else if (msg.getMsgType().equals(WechatConsts.MSG_TYPE_VIDEO)) {
			System.out.println("这是视频消息");
			System.out.println("视频缩略图媒体id：" + msg.getThumbMediaId());
			System.out.println("视频媒体文件id：" + msg.getMediaId());
		} else if (msg.getMsgType().equals(WechatConsts.MSG_TYPE_LOCATION)) {
			System.out.println("这是用户选择的位置消息");
			System.out.println("地理位置纬度：" + msg.getLocationX());
			System.out.println("地理位置经度：" + msg.getLocationY());
			System.out.println("地图缩放大小：" + msg.getScale());
			System.out.println("地理位置信息：" + msg.getLabel());
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_LOCATION)) {
			System.out.println("这是自动上报的位置消息");
			System.out.println("地理位置纬度：" + msg.getLatitude());
			System.out.println("地理位置经度：" + msg.getLongitude());
			System.out.println("地理位置精度：" + msg.getPrecision());
		} else {
			System.out.println(msg);
		}

		// -------演示回复消息---------
		// 文本消息
		WechatOutTextMessage txtMsg = new WechatOutTextMessage(msg);
		txtMsg.setContent("Hi，" + msg.getContent());
		// 图文消息
		WechatOutNewsMessage newsMsg = new WechatOutNewsMessage(msg);
		WechatOutNewsMessage.Item newsItem1 = new WechatOutNewsMessage.Item();
		newsItem1.setTitle("企业号没有应用，但你可以用AWS PaaS开发更多");
		newsItem1.setDescription("AWS PaaS为降低微信企业号开发者的学习门槛，提高用户一致体验，对微信企业号的开放API进行了底层框架封装，能够利用AWS PaaS强大的后端集成能力和MVC开发框架，更加快速的为微信企业号开发和分发H5页面应用。");
		newsItem1.setPicUrl("https://docs.awspaas.com/reference-guide/aws-paas-wechat-reference-guide/wechat.png");
		newsItem1.setUrl("https://docs.awspaas.com/reference-guide/aws-paas-wechat-reference-guide/index.html");
		WechatOutNewsMessage.Item newsItem2 = new WechatOutNewsMessage.Item();
		newsItem2.setTitle("你好，这是标题2-" + msg.getContent());
		newsItem2.setUrl("http://www.awspaas.com");
		newsMsg.addArticle(newsItem1);
		newsMsg.addArticle(newsItem2);
		// 图片消息
		WechatOutImageMessage imgMsg = new WechatOutImageMessage(msg);
		imgMsg.setMediaId("1GdxAdpMzsVOREZAM0YMZq0NT3uckBAP2CDkNTHLyhBK9rrRKgdPQT6ZzIgp22JGBx2eUAFG1QwiPQbyICZe6AA");
		// 语音消息
		WechatOutVoiceMessage voiceMsg = new WechatOutVoiceMessage(msg);
		voiceMsg.setMediaId("12HuntdV7Z6ItQZs8DObEPpE6emJgMuUuvbpQ-SUUyBJX5UX2T4pDv3HHtR8QNX8gDhFW0w31xRX3tk32yUkgsQ");
		// 视频消息
		WechatOutVideoMessage videoMsg = new WechatOutVideoMessage(msg);
		videoMsg.setMediaId("1c7a58m46ywkm6O_p-qqd2jvvuqJNz1ICz2daHPxk5h0cIgKnlrHxE1_gWdJlbheWGjagBSKVtxrkfh-JACx2DQ");
		videoMsg.setTitle("这是视频标题");
		videoMsg.setDescription("这是视频内容说明");

		// -------演示处理事件---------
		if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_SUBSCRIBE)) {
			// 图文消息
			WechatOutNewsMessage helpMsg = new WechatOutNewsMessage(msg);
			WechatOutNewsMessage.Item helpMsgItem = new WechatOutNewsMessage.Item();
			helpMsgItem.setTitle("微信企业号应用开发参考文档");
			helpMsgItem.setDescription("AWS PaaS为降低微信企业号开发者的学习门槛，提高用户一致体验，对微信企业号的开放API进行了底层框架封装，能够利用AWS PaaS强大的后端集成能力和MVC开发框架，更加快速的为微信企业号开发和分发H5页面应用。");
			helpMsgItem.setPicUrl("https://docs.awspaas.com/reference-guide/aws-paas-wechat-reference-guide/wechat.png");
			helpMsgItem.setUrl("https://docs.awspaas.com/reference-guide/aws-paas-wechat-reference-guide/index.html");
			helpMsg.addArticle(helpMsgItem);
			return helpMsg;
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_UNSUBSCRIBE)) {
			System.out.println("取消关注人：" + msg.getFromUserName());
			// todo
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_ENTER_AGENT)) {
			System.out.println("发现成员进入了这个应用：" + msg.getFromUserName());
			// 例如，检查是否有待处理的新订单，如果有组织前6条记录使用图文链接发送消息
			WechatOutNewsMessage orderMsg = new WechatOutNewsMessage(msg);
			for (int i = 1; i < 7; i++) {
				WechatOutNewsMessage.Item orderItem = new WechatOutNewsMessage.Item();
				orderItem.setTitle("采购订单#" + i);
				orderItem.setPicUrl("http://www.awspal.com/images/functions/process-element.png");
				orderItem.setDescription("这是XX客户的#" + i + "采购订单，请审批");
				orderItem.setUrl("https://docs.awspaas.com/reference-guide/aws-paas-wechat-reference-guide/index.html");
				orderMsg.addArticle(orderItem);
			}
			return orderMsg;
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_LOCATION)) {
			WechatOutTextMessage locationMsg = new WechatOutTextMessage(msg);
			locationMsg.setContent("这是自动上报的位置消息。\n纬度:" + msg.getLatitude() + "\n经度:" + msg.getLongitude() + "\n精度:" + msg.getPrecision());
			return locationMsg;
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_VIEW)) {
			System.out.println("这是菜单URL：" + msg.getEventKey());
			// todo，你想在用户点击该菜单时做些什么吗
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_PIC_SYSPHOTO)) {
			System.out.println("收到一张名片拍照：" + msg.getFromUserName());
			// 实际上图片文件并未包含在该信息，再等待微信接口callback一个图片消息
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_SCANCODE_WAITMSG)) {
			System.out.println("收到一个扫码：" + msg.getScanCodeInfo().getScanResult());
			// todo，你想在用户点击该菜单时做些什么吗
			// 例如查询对应的业务单据，返回图文消息链接
		} else if (msg.getEvent().equals(WechatConsts.EVENT_TYPE_LOCATION_SELECT)) {
			System.out.println("这是用户选择的位置消息");
			System.out.println("地理位置纬度：" + msg.getLocationX());
			System.out.println("地理位置经度：" + msg.getLocationY());
			System.out.println("地图缩放大小：" + msg.getScale());
			System.out.println("地理位置信息：" + msg.getLabel());
			// todo，你想在用户点击该菜单时做些什么吗
		}

		return imgMsg;
	}
}
